@@ -1,4 +1,4 @@
-def set_profile_8MID12_1_N(lib, id):
+def set_profile_8MID60_4_N(lib, id):
     worst_result = Result.Ok
     result = Result.Ok
 
@@ -10,7 +10,7 @@ def set_profile_8MID12_1_N(lib, id):
         FEEDBACK_NONE = 5
         FEEDBACK_EMF = 4
         FEEDBACK_ENCODER = 1
-    feedback_settings.FeedbackType = FeedbackType_.FEEDBACK_NONE
+    feedback_settings.FeedbackType = FeedbackType_.FEEDBACK_EMF
     class FeedbackFlags_:
         FEEDBACK_ENC_TYPE_BITS = 192
         FEEDBACK_ENC_TYPE_DIFFERENTIAL = 128
@@ -27,11 +27,11 @@ def set_profile_8MID12_1_N(lib, id):
 
     home_settings = home_settings_t()
 
-    home_settings.FastHome = 50
+    home_settings.FastHome = 500
     home_settings.uFastHome = 0
     home_settings.SlowHome = 500
     home_settings.uSlowHome = 0
-    home_settings.HomeDelta = 1020
+    home_settings.HomeDelta = 500
     home_settings.uHomeDelta = 0
     class HomeFlags_:
         HOME_USE_FAST = 256
@@ -56,11 +56,11 @@ def set_profile_8MID12_1_N(lib, id):
 
     move_settings = move_settings_t()
 
-    move_settings.Speed = 800
+    move_settings.Speed = 2000
     move_settings.uSpeed = 0
-    move_settings.Accel = 3200
-    move_settings.Decel = 4800
-    move_settings.AntiplaySpeed = 800
+    move_settings.Accel = 2000
+    move_settings.Decel = 5000
+    move_settings.AntiplaySpeed = 2000
     move_settings.uAntiplaySpeed = 0
     class MoveFlags_:
         RPM_DIV_1000 = 1
@@ -73,9 +73,9 @@ def set_profile_8MID12_1_N(lib, id):
 
     engine_settings = engine_settings_t()
 
-    engine_settings.NomVoltage = 50
-    engine_settings.NomCurrent = 200
-    engine_settings.NomSpeed = 1600
+    engine_settings.NomVoltage = 360
+    engine_settings.NomCurrent = 670
+    engine_settings.NomSpeed = 5000
     engine_settings.uNomSpeed = 0
     class EngineFlags_:
         ENGINE_LIMIT_RPM = 128
@@ -86,8 +86,8 @@ def set_profile_8MID12_1_N(lib, id):
         ENGINE_MAX_SPEED = 4
         ENGINE_CURRENT_AS_RMS = 2
         ENGINE_REVERSE = 1
-    engine_settings.EngineFlags = EngineFlags_.ENGINE_LIMIT_RPM | EngineFlags_.ENGINE_ACCEL_ON | EngineFlags_.ENGINE_REVERSE
-    engine_settings.Antiplay = 326
+    engine_settings.EngineFlags = EngineFlags_.ENGINE_LIMIT_RPM | EngineFlags_.ENGINE_ACCEL_ON
+    engine_settings.Antiplay = 1800
     class MicrostepMode_:
         MICROSTEP_MODE_FRAC_256 = 9
         MICROSTEP_MODE_FRAC_128 = 8
@@ -99,7 +99,7 @@ def set_profile_8MID12_1_N(lib, id):
         MICROSTEP_MODE_FRAC_2 = 2
         MICROSTEP_MODE_FULL = 1
     engine_settings.MicrostepMode = MicrostepMode_.MICROSTEP_MODE_FRAC_256
-    engine_settings.StepsPerRev = 20
+    engine_settings.StepsPerRev = 200
     result = lib.set_engine_settings(id, byref(engine_settings))
 
     if result != Result.Ok:
@@ -181,10 +181,10 @@ def set_profile_8MID12_1_N(lib, id):
         ENDER_SW2_ACTIVE_LOW = 4
         ENDER_SW1_ACTIVE_LOW = 2
         ENDER_SWAP = 1
-    edges_settings.EnderFlags = EnderFlags_.ENDER_SW2_ACTIVE_LOW | EnderFlags_.ENDER_SW1_ACTIVE_LOW | EnderFlags_.ENDER_SWAP
-    edges_settings.LeftBorder = -971
+    edges_settings.EnderFlags = EnderFlags_.ENDER_SW2_ACTIVE_LOW | EnderFlags_.ENDER_SW1_ACTIVE_LOW
+    edges_settings.LeftBorder = -251
     edges_settings.uLeftBorder = 0
-    edges_settings.RightBorder = 910
+    edges_settings.RightBorder = 9219
     edges_settings.uRightBorder = 0
     result = lib.set_edges_settings(id, byref(edges_settings))
 
@@ -197,8 +197,8 @@ def set_profile_8MID12_1_N(lib, id):
     pid_settings.KpU = 0
     pid_settings.KiU = 0
     pid_settings.KdU = 0
-    pid_settings.Kpf = 0.003599999938160181
-    pid_settings.Kif = 0.03799999877810478
+    pid_settings.Kpf = 0.006000000052154064
+    pid_settings.Kif = 0.05000000074505806
     pid_settings.Kdf = 2.8000000384054147e-05
     result = lib.set_pid_settings(id, byref(pid_settings))
 
@@ -290,9 +290,9 @@ def set_profile_8MID12_1_N(lib, id):
 
     control_settings = control_settings_t()
 
-    control_settings.MaxSpeed[0] = 80
-    control_settings.MaxSpeed[1] = 800
-    control_settings.MaxSpeed[2] = 0
+    control_settings.MaxSpeed[0] = 20
+    control_settings.MaxSpeed[1] = 200
+    control_settings.MaxSpeed[2] = 2000
     control_settings.MaxSpeed[3] = 0
     control_settings.MaxSpeed[4] = 0
     control_settings.MaxSpeed[5] = 0
@@ -400,9 +400,9 @@ def set_profile_8MID12_1_N(lib, id):
 
     emf_settings = emf_settings_t()
 
-    emf_settings.L = 0
-    emf_settings.R = 0
-    emf_settings.Km = 0
+    emf_settings.L = 0.005400000140070915
+    emf_settings.R = 7.400000095367432
+    emf_settings.Km = 0.0024999999441206455
     class BackEMFFlags_:
         BACK_EMF_KM_AUTO = 4
         BACK_EMF_RESISTANCE_AUTO = 2
@@ -446,7 +446,7 @@ def set_profile_8MID12_1_N(lib, id):
     stage_information = stage_information_t()
 
     stage_information.Manufacturer = bytes([83, 116, 97, 110, 100, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0])
-    stage_information.PartNumber = bytes([56, 77, 73, 68, 49, 50, 45, 49, 45, 78, 0, 0, 55, 0, 53, 0, 0, 52, 48, 68, 45, 69, 65, 83])
+    stage_information.PartNumber = bytes([56, 77, 73, 68, 54, 48, 45, 52, 45, 78, 0, 78, 0, 0, 53, 0, 0, 52, 48, 68, 45, 69, 65, 83])
     result = lib.set_stage_information(id, byref(stage_information))
 
     if result != Result.Ok:
@@ -458,9 +458,9 @@ def set_profile_8MID12_1_N(lib, id):
     stage_settings.LeadScrewPitch = 0.25
     stage_settings.Units = bytes([109, 109, 0, 114, 101, 101, 0, 0])
     stage_settings.MaxSpeed = 0
-    stage_settings.TravelRange = 11
-    stage_settings.SupplyVoltageMin = 5
-    stage_settings.SupplyVoltageMax = 12
+    stage_settings.TravelRange = 56
+    stage_settings.SupplyVoltageMin = 12
+    stage_settings.SupplyVoltageMax = 36
     stage_settings.MaxCurrentConsumption = 0
     stage_settings.HorizontalLoadCapacity = 0
     stage_settings.VerticalLoadCapacity = 0
@@ -505,7 +505,7 @@ def set_profile_8MID12_1_N(lib, id):
     motor_settings.SpeedConstant = 0
     motor_settings.SpeedTorqueGradient = 0
     motor_settings.MechanicalTimeConstant = 0
-    motor_settings.MaxSpeed = 1600
+    motor_settings.MaxSpeed = 5000
     motor_settings.MaxCurrent = 0
     motor_settings.MaxCurrentTime = 0
     motor_settings.NoLoadCurrent = 0
@@ -581,8 +581,8 @@ def set_profile_8MID12_1_N(lib, id):
 
     gear_settings = gear_settings_t()
 
-    gear_settings.ReductionIn = 9
-    gear_settings.ReductionOut = 4
+    gear_settings.ReductionIn = 0
+    gear_settings.ReductionOut = 0
     gear_settings.RatedInputTorque = 0
     gear_settings.RatedInputSpeed = 0
     gear_settings.MaxOutputBacklash = 0
@@ -614,7 +614,7 @@ def set_profile_8MID12_1_N(lib, id):
         TS_TYPE_SEMICONDUCTOR = 2
         TS_TYPE_THERMOCOUPLE = 1
         TS_TYPE_UNKNOWN = 0
-    accessories_settings.TSSettings = TSSettings_.TS_TYPE_THERMOCOUPLE | TSSettings_.TS_TYPE_UNKNOWN
+    accessories_settings.TSSettings = TSSettings_.TS_TYPE_UNKNOWN
     class LimitSwitchesSettings_:
         LS_SHORTED = 16
         LS_SW2_ACTIVE_LOW = 8
